@@ -1,18 +1,18 @@
-"""Main module."""
-import os
+"""Library module."""
 import logging
+import os
 import re
 import urllib.parse
+from typing import List, Optional
 
 import click
 from debian.changelog import Changelog
 from debian.debian_support import Version
 from lazr.restfulclient.errors import NotFound
+from models import Change
 
 
-def get_source_package_details(
-    ubuntu, launchpad, lp_arch_series, binary_package_name, binary_package_version, ppas
-):
+def get_source_package_details(ubuntu, launchpad, lp_arch_series, binary_package_name, binary_package_version, ppas):
     # find the published binary for this series, binary_package_name
     # and binary_package_version
     source_package_name = None
@@ -51,9 +51,7 @@ def get_source_package_details(
                 source_package_version = binaries[0].source_package_version
     if not source_package_name or not source_package_version:
         raise click.ClickException(
-            "Unable to find source package for {} {}".format(
-                binary_package_name, binary_package_version
-            )
+            "Unable to find source package for {} {}".format(binary_package_name, binary_package_version)
         )
     return source_package_name, source_package_version
 
@@ -69,15 +67,10 @@ def _parse_cve_details(changelog_block, launchpad):
     changelog_block_cves = []
     for change in changelog_block:
         if "CVE" in change:
-            cve_pos = [
-                (m.start(), m.end()) for m in re.finditer(r"CVE-\d+-\d+", change)
-            ]
+            cve_pos = [(m.start(), m.end()) for m in re.finditer(r"CVE-\d+-\d+", change)]
             for start, end in cve_pos:
                 cve = change[start:end].strip()
-                if cve not in [
-                    changelog_block_cve["cve"]
-                    for changelog_block_cve in changelog_block_cves
-                ]:
+                if cve not in [changelog_block_cve["cve"] for changelog_block_cve in changelog_block_cves]:
                     cve_details = {}
                     cve_details["cve"] = cve
                     cve_details["url"] = _get_cve_url(cve)
@@ -88,9 +81,7 @@ def _parse_cve_details(changelog_block, launchpad):
                     cve_public_date = ""
                     for cve_details_line in cve_details_lines:
                         # only get the CVE description if the user has requested it
-                        if not cve_ubuntu_description and cve_details_line.startswith(
-                            "Ubuntu-Description:"
-                        ):
+                        if not cve_ubuntu_description and cve_details_line.startswith("Ubuntu-Description:"):
                             # get the string in the line after the Ubuntu-Description: line
                             # while the next line is not 'Notes' keep appending to cve_description
                             while True:
@@ -98,9 +89,7 @@ def _parse_cve_details(changelog_block, launchpad):
                                 if next_line.startswith("Notes"):
                                     break
                                 cve_ubuntu_description += next_line
-                        if not cve_description and cve_details_line.startswith(
-                            "Description:"
-                        ):
+                        if not cve_description and cve_details_line.startswith("Description:"):
                             # get the string in the line after the Description: line
                             # while the next line is not 'Notes' keep appending to cve_description
                             while True:
@@ -109,18 +98,12 @@ def _parse_cve_details(changelog_block, launchpad):
                                     break
                                 cve_description += next_line
                         if "Priority:" in cve_details_line:
-                            cve_priority = cve_details_line.split("Priority:")[
-                                1
-                            ].strip()
+                            cve_priority = cve_details_line.split("Priority:")[1].strip()
                         if "PublicDate:" in cve_details_line:
-                            cve_public_date = cve_details_line.split("PublicDate:")[
-                                1
-                            ].strip()
+                            cve_public_date = cve_details_line.split("PublicDate:")[1].strip()
 
                     cve_details["cve_description"] = (
-                        cve_ubuntu_description.lstrip()
-                        if cve_ubuntu_description
-                        else cve_description.lstrip()
+                        cve_ubuntu_description.lstrip() if cve_ubuntu_description else cve_description.lstrip()
                     )
                     cve_details["cve_priority"] = cve_priority
                     cve_details["cve_public_date"] = cve_public_date
@@ -140,10 +123,8 @@ def _get_cve_details(cve, launchpad):
     possible_cve_detail_locations = ["active", "retired", "ignored"]
     for possible_cve_detail_location in possible_cve_detail_locations:
         try:
-            cve_details_url = (
-                "https://git.launchpad.net/ubuntu-cve-tracker/plain/{}/{}".format(
-                    possible_cve_detail_location, cve
-                )
+            cve_details_url = "https://git.launchpad.net/ubuntu-cve-tracker/plain/{}/{}".format(
+                possible_cve_detail_location, cve
             )
             cve_details_resp = launchpad._browser.get(cve_details_url).decode("utf-8")
             cve_details_lines = iter(cve_details_resp.splitlines())
@@ -154,12 +135,12 @@ def _get_cve_details(cve, launchpad):
 
 
 def parse_changelog(
-    launchpad,
-    changelog_filename,
-    from_version=None,
-    to_version=None,
-    count=1,
-    highlight_cves=False,
+    launchpad: object,
+    changelog_filename: str,
+    from_version: str = None,
+    to_version: str = None,
+    count: Optional[int] = 1,
+    highlight_cves: bool = False,
 ):
     """
     Extract changelog entries within a version range
@@ -170,24 +151,14 @@ def parse_changelog(
     list of changelog entries the result will be incomplete and
     a non-empty error message is returned to indicate the issue.
     """
-    changelog = ""
-    changelogs = []
+    changelogs: List[Change] = []
     if not to_version:
         raise Exception("to_version must be specified when parsing changelog")
 
     with open(changelog_filename, "r") as fileptr:
         try:
             parsed_changelog = Changelog(fileptr.read())
-            changelog += "Source: {}\n".format(parsed_changelog.get_package())
-            changelog += "Version: {}\n".format(parsed_changelog.version)
-            changelog += "Distribution: {}\n".format(parsed_changelog.distributions)
-            changelog += "Urgency: {}\n".format(parsed_changelog.urgency)
-            changelog += "Maintainer: {}\n".format(parsed_changelog.author)
-            changelog += "Date: {}\n".format(parsed_changelog.date)
             # The changelog blocks are in reverse order; we'll see high|to before low|from.
-            change_blocks = []
-            launchpad_bugs_fixed = []
-            cves_referenced = []
             for changelog_block in parsed_changelog:
                 if changelog_block.version:
                     # if changelog_block.version is None then this is a
@@ -197,56 +168,35 @@ def parse_changelog(
                     ) <= Version(to_version)
 
                     if from_version:
-                        if Version(changelog_block.version.full_version) <= Version(
-                            from_version
-                        ):
+                        if Version(changelog_block.version.full_version) <= Version(from_version):
                             # If we have reached our from version then we can
                             # stop parsing
                             break
 
                     if changelog_version_equal_to_or_before_to_version:
-                        changelog_dict = {}
-                        # Attempt to parse theCVEs referenced in the changelo entries
+                        # Attempt to parse theCVEs referenced in the changelog entries
+                        cves = []
                         if highlight_cves:
-                            cves = _parse_cve_details(
-                                changelog_block.changes(), launchpad
-                            )
-                            cves_referenced += cves
-                            changelog_dict["cves"] = cves
-                        launchpad_bugs_fixed += changelog_block.lp_bugs_closed
-                        changeblock_summary = "{} ({}) {}; urgency={}".format(
-                            changelog_block.package,
-                            changelog_block.version,
-                            changelog_block.distributions,
-                            changelog_block.urgency,
-                        )
-                        change_blocks.append((changeblock_summary, changelog_block))
-                        changelog_dict["log"] = []
-                        for change in changelog_block.changes():
-                            changelog_dict["log"].append(change)
-                        changelog_dict["package"] = changelog_block.package
-                        changelog_dict["version"] = str(changelog_block.version)
-                        changelog_dict["urgency"] = changelog_block.urgency
-                        changelog_dict["distributions"] = changelog_block.distributions
-                        changelog_dict[
-                            "launchpad_bugs_fixed"
-                        ] = changelog_block.lp_bugs_closed
-                        changelog_dict["author"] = changelog_block.author
-                        changelog_dict["date"] = changelog_block.date
+                            cves = _parse_cve_details(changelog_block.changes(), launchpad)
 
-                        changelogs.append(changelog_dict)
-                    if count and len(change_blocks) == count:
+                        changelog_change = Change(
+                            package=changelog_block.package,
+                            version=str(changelog_block.version),
+                            urgency=changelog_block.urgency,
+                            distributions=changelog_block.distributions,
+                            launchpad_bugs_fixed=changelog_block.lp_bugs_closed,
+                            author=changelog_block.author,
+                            date=changelog_block.date,
+                            log=changelog_block.changes(),
+                            cves=cves,
+                        )
+                        changelogs.append(changelog_change)
+                    if count and len(changelogs) == count:
                         break  # we have enough blocks now
 
-            changelog += "Launchpad-Bugs-Fixed: {}\n".format(launchpad_bugs_fixed)
-            changelog += "Changes:\n"
-            for changeblock_summary, change_block in change_blocks:
-                changelog += "{}\n".format(changeblock_summary)
-                for change in change_block.changes():
-                    changelog += "{}\n".format(change)
             # log a warning if we have no changelog or
             # from_version  ot found or to_version not found
-            if not changelog:
+            if not changelogs:
                 logging.warning(
                     "Unable to parse changelog {} for versions {} to {}".format(
                         changelog_filename, from_version, to_version
@@ -254,11 +204,9 @@ def parse_changelog(
                 )
         except Exception as ex:
             raise ex
-            raise Exception(
-                "Unable to parse package changelog {}".format(changelog_filename)
-            )
+            raise Exception("Unable to parse package changelog {}".format(changelog_filename))
 
-        return changelog, cves_referenced, changelogs
+        return changelogs
 
 
 def get_changelog(
@@ -353,16 +301,11 @@ def get_changelog(
                         package_version_in_ppa_changelog = True
                         break  # no need to continue iterating the PPA list
 
-        if (
-            not package_version_in_archive_changelog
-            and not package_version_in_ppa_changelog
-        ):
+        if not package_version_in_archive_changelog and not package_version_in_ppa_changelog:
             # can be found for this package and package version
             cache_file.write(
                 "Unable to find changelog for srouce package {} "
-                "version {}.".format(
-                    source_package_name, source_package_version
-                ).encode("utf-8")
+                "version {}.".format(source_package_name, source_package_version).encode("utf-8")
             )
 
     return cache_filename
